.. :changelog:

History
-------

0.1.0 (2017-12-29)
++++++++++++++++++

* First release on PyPI.
* Initial models and REST API.

0.2.0 (2018-01-05)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.1.0...v0.2.0)>`_

* Added REST API filters.
* Added URLs to pubmed article and NCBI utils.

0.2.1 (2018-01-09)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.1.0...v0.2.0)>`_

* Fixed issues with migrations

0.2.2 (2018-01-12)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.1.0...v0.2.0)>`_

* Fixed route names for SimpleRouter.

0.3.0 (2018-02-09)
++++++++++++++++++

`Full Changelog <https://github.com/chopdgd/django-literature-knowledgebase/compare/v0.1.0...v0.2.0)>`_

* updated requirements to the latest.
